package com.ruoyi.ibs.dashboard.mapper;

import com.ruoyi.ibs.dashboard.domain.LscjAmountRules;

import java.util.List;


/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author ruoyi
 * @date 2025-08-04
 */
public interface LscjAmountRulesMapper 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param orgId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public LscjAmountRules selectLscjAmountRulesById(String Id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param lscjAmountRules 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<LscjAmountRules> selectLscjAmountRulesList(LscjAmountRules lscjAmountRules);

    public int selectLscjAmountRulesListCount(LscjAmountRules lscjAmountRules);
    /**
     * 新增【请填写功能名称】
     * 
     * @param lscjAmountRules 【请填写功能名称】
     * @return 结果
     */
    public int insertLscjAmountRules(LscjAmountRules lscjAmountRules);

    /**
     * 修改【请填写功能名称】
     * 
     * @param lscjAmountRules 【请填写功能名称】
     * @return 结果
     */
    public int updateLscjAmountRules(LscjAmountRules lscjAmountRules);

    /**
     * 删除【请填写功能名称】
     * 
     * @param orgId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteLscjAmountRulesByOrgId(String orgId);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param orgIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLscjAmountRulesByIds(String[] Ids);
}
