package com.ruoyi.ibs.dashboard.controller;

import java.util.ArrayList;
import java.util.List;
import java.util.UUID;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.page.PageDomain;
import com.ruoyi.common.core.page.TableSupport;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.ibs.dashboard.domain.LscjAmountRules;
import com.ruoyi.ibs.dashboard.domain.vo.LscjAmountRulesVo;
import com.ruoyi.ibs.dashboard.domain.vo.LscjSysuserVo;
import com.ruoyi.ibs.dashboard.service.ILscjAmountRulesService;
import com.ruoyi.ibs.list.domain.SysGroupCustomer;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 【请填写功能名称】Controller
 * 
 * @author ruoyi
 * @date 2025-08-04
 */
@RestController
@Api(tags = "实时参数配置-金额")
@RequestMapping("/system/lscjAmount")
public class LscjAmountRulesController extends BaseController
{
    @Autowired
    private ILscjAmountRulesService lscjAmountRulesService;

    /**
     * 查询【请填写功能名称】列表
     */

    @GetMapping("/list")
    @ApiOperation(value = "查询")
    public LscjAmountRulesVo list(LscjAmountRules lscjAmountRules)
    {

        LscjAmountRulesVo vo = new LscjAmountRulesVo();
        vo.setRows(lscjAmountRulesService.selectLscjAmountRulesList(lscjAmountRules));
        vo.setTotal(lscjAmountRulesService.selectLscjAmountRulesListCount(lscjAmountRules));
        return  vo;
    }

    /**
     * 导出【请填写功能名称】列表
     */



    /**
     * 获取【请填写功能名称】详细信息
     */

    @GetMapping(value = "/{id}")
    @ApiOperation(value = "机构号-查询")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(lscjAmountRulesService.selectLscjAmountRulesById(id));
    }

    /**
     * 新增【请填写功能名称】
     */

    @PostMapping
    @ApiOperation(value = "新增")
    public AjaxResult add(@RequestBody LscjAmountRules lscjAmountRules)
    {
        return toAjax(lscjAmountRulesService.insertLscjAmountRules(lscjAmountRules));
    }

    /**
     * 修改【请填写功能名称】
     */

    @PutMapping
    @ApiOperation(value = "编辑")
    public AjaxResult edit(@RequestBody LscjAmountRules lscjAmountRules)
    {
        return toAjax(lscjAmountRulesService.updateLscjAmountRules(lscjAmountRules));
    }

    /**
     * 删除【请填写功能名称】
     */

	@DeleteMapping("/{Ids}")
    @ApiOperation(value = "删除")
    public AjaxResult remove(@PathVariable String[] Ids)
    {
        return toAjax(lscjAmountRulesService.deleteLscjAmountRulesByIds(Ids));
    }
}
